@@ -2278,6 +2278,13 @@ define([
             this.setPreview(code.toString());
         }
 
+        // display
+        if (this.useCell) {
+            if (allocation && this.state.allocateTo != '') {
+                code.appendLine();
+                code.append(this.state.allocateTo);
+            }
+        }
         return code.toString();
     }
 
